@@ -15,7 +15,7 @@ use Rose::HTML::Form::Field;
 use Rose::HTML::Form::Field::Collection;
 our @ISA = qw(Rose::HTML::Form::Field Rose::HTML::Form::Field::Collection);
 
-our $VERSION = '0.544';
+our $VERSION = '0.545';
 
 # Multiple inheritence never quite works out the way I want it to...
 Rose::HTML::Form::Field::Collection->import_methods
@@ -351,6 +351,48 @@ sub param_exists
 
 sub params_exist { (keys %{$_[0]->{'params'}}) ? 1 : 0 }
 
+sub param_exists_for_field
+{
+  my($self, $name) = @_;
+
+  $name = $name->name  if(UNIVERSAL::isa($name, 'Rose::HTML::Form::Field'));
+
+  return 0  unless($self->field($name));
+
+  my $nibble = $name;
+  my $found_form = 0;
+
+  while(length $nibble)
+  {
+    if($self->form($nibble) && !$self->field($nibble))
+    {
+      $found_form = 1;
+      last;
+    }
+
+    return 1  if($self->param_exists($nibble));
+    $nibble =~ s/\.[^.]+$// || last;
+  }
+
+  foreach my $field ($found_form ? $self->form($nibble)->fields : 
+                                   $self->field($name))
+  {
+    if($field->can('subfield_names'))
+    {
+      foreach my $subname ($field->subfield_names)
+      {
+        # Skip unrelated subfields
+        next unless(index($name, $subname) == 0 || 
+                    index($subname, $name) == 0);
+
+        return 1  if($self->param_exists($subname));
+      }
+    }
+  }
+
+  return 0;
+}
+
 sub param_value_exists
 {
   my($self, $param, $value) = @_;
@@ -852,6 +894,9 @@ sub add_forms
 
       $name = $form->form_name;
 
+      croak "Cannot add form with the same name as an existing field: $name"
+        if($self->field($name));
+
       unless(defined $form->rank)
       {
         $form->rank($self->increment_form_rank_counter);
@@ -862,6 +907,9 @@ sub add_forms
       $name = $arg;
       $form = shift;
 
+      croak "Cannot add form with the same name as an existing field: $name"
+        if($self->field($name));
+
       if(UNIVERSAL::isa($form, 'Rose::HTML::Form'))
       {
         if(refaddr($form) eq refaddr($self))
@@ -1142,9 +1190,15 @@ sub fields
   [
     grep { defined } 
     map 
-    { 
-      /$FF_SEPARATOR_RE([^$FF_SEPARATOR_RE]+)/ || /(.*)/;
-      $fields->{$1} || $fields_by_name->{$1} || $self->field($_)
+    {       
+      if(/$FF_SEPARATOR_RE([^$FF_SEPARATOR_RE]+)/o)
+      {
+        $self->field($_) || $fields->{$1} || $fields_by_name->{$1};
+      }
+      else
+      {
+        $fields->{$_} || $fields_by_name->{$_} || $self->field($_);
+      }
     } 
     $self->field_monikers 
   ];
@@ -1701,6 +1755,8 @@ A simple scalar followed by an object that "isa" L<Rose::HTML::Form::Field> is s
 
 Each field's L<parent_form|Rose::HTML::Form::Field/parent_form> is set to the form object.  If the field's L<rank|Rose::HTML::Form::Field/rank> is undefined, it's set to the value of the form's L<field_rank_counter|/field_rank_counter> attribute and the rank counter is incremented.
 
+Adding a field with the same name as an existing L<sub-form|/"NESTED FORMS"> will cause a fatal error.
+
 Examples:
 
     # Name/hashref pairs
@@ -1758,6 +1814,8 @@ If the name contains any dots (".") it will be taken as a hierarchical name and
 
 Each form's L<parent_form|/parent_form> is set to the form object it was added to.  If the form's L<rank|/rank> is undefined, it's set to the value of the form's L<form_rank_counter|/field_rank_counter> attribute and the rank counter is incremented.
 
+Adding a form with the same name as an existing field will cause a fatal error.
+
 Examples:
 
     $a_form = Rose::HTML::Form->new(...);
@@ -1991,6 +2049,9 @@ The default mapping of type names to class names is:
 
   'hidden'             => Rose::HTML::Form::Field::Hidden
 
+  'int'                => Rose::HTML::Form::Field::Integer,
+  'integer'            => Rose::HTML::Form::Field::Integer,
+
   'email'              => Rose::HTML::Form::Field::Email
 
   'phone'              => Rose::HTML::Form::Field::PhoneNumber::US
@@ -2330,6 +2391,38 @@ Returns true if any parameters exist, false otherwise.
 
 Returns true if a parameter named NAME exists, false otherwise.
 
+=item B<param_exists_for_field [ NAME | FIELD ]>
+
+Returns true if a L<param|/param> exists that addresses the field named NAME or the L<Rose::HTML::Form::Field>-derived object FIELD, false otherwise.
+
+This method is useful for determining if any query parameters exist that address a compound field.  For example, a compound field named C<a.b.c.d> could be addressed by any one of the following query parameters: C<a>, C<a.b>, C<a.b.c>, or C<a.b.c.d>.  This method also works with fields inside L<sub-form|/"NESTED FORMS">.  Examples:
+
+    $form = Rose::HTML::Form->new;
+    $form->add_field(when => { type => 'datetime split mdyhms' });
+
+    $form->params({ 'when.date' => '2004-01-02' });
+
+    $form->param_exists_for_field('when');            # true
+    $form->param_exists_for_field('when.date');       # true
+    $form->param_exists_for_field('when.date.month'); # true
+    $form->param_exists_for_field('when.time.hour');  # false
+
+    $subform = Rose::HTML::Form->new;
+    $subform->add_field(subwhen => { type => 'datetime split mdyhms' });
+    $form->add_form(subform => $subform);
+
+    $form->params({ 'subform.subwhen.date' => '2004-01-02' });
+
+    $form->param_exists_for_field('subform.subwhen');            # true
+    $form->param_exists_for_field('subform.subwhen.date');       # true
+    $form->param_exists_for_field('subform.subwhen.date.month'); # true
+    $form->param_exists_for_field('subform.subwhen.time.hour');  # false
+
+    $form->param_exists_for_field('when');            # false
+    $form->param_exists_for_field('when.date');       # false
+    $form->param_exists_for_field('when.date.month'); # false
+    $form->param_exists_for_field('when.time.hour');  # false
+
 =item B<params_from_apache APR>
 
 Set L<params|/params> by extracting parameter names and values from an apache request object.  Calling this method entirely replaces the previous L<params|/params>.
