@@ -15,7 +15,7 @@ use Rose::HTML::Form::Constants qw(FF_SEPARATOR);
 # Variables for use in regexes
 our $FF_SEPARATOR_RE = quotemeta FF_SEPARATOR;
 
-our $VERSION = '0.54';
+our $VERSION = '0.545';
 
 #
 # Class data
@@ -81,6 +81,9 @@ __PACKAGE__->field_type_classes
 
   'hidden'             => 'Rose::HTML::Form::Field::Hidden',
 
+  'int'                => 'Rose::HTML::Form::Field::Integer',
+  'integer'            => 'Rose::HTML::Form::Field::Integer',
+
   'email'              => 'Rose::HTML::Form::Field::Email',
 
   'phone'              => 'Rose::HTML::Form::Field::PhoneNumber::US',
@@ -305,6 +308,12 @@ sub add_fields
 
       $field->local_name($field->name);
 
+      if($self->can('form') && $self->form($field->local_name))
+      {
+        Carp::croak "Cannot add field with the same name as an existing sub-form: ", 
+                    $field->local_name;
+      }
+
       unless(defined $field->rank)
       {
         $field->rank($self->increment_field_rank_counter);
@@ -317,6 +326,11 @@ sub add_fields
     {
       my $field = shift;
 
+      if($self->can('form') && $self->form($arg))
+      {
+        Carp::croak "Cannot add field with the same name as an existing sub-form: $arg";
+      }
+
       if(UNIVERSAL::isa($field, 'Rose::HTML::Form::Field'))
       {
         if(refaddr($field) eq refaddr($self))
@@ -370,6 +384,25 @@ sub children
   return wantarray ? shift->fields() : (shift->fields() || []);
 }
 
+sub subfield_names
+{
+  my($self) = shift;
+
+  my @names;
+
+  foreach my $field ($self->fields)
+  {
+    push(@names, $field->name, ($field->can('_subfield_names') ? $field->_subfield_names : ()));
+  }
+
+  return wantarray ? @names : \@names;
+}
+
+sub _subfield_names
+{
+  map { $_->can('subfield_names') ? $_->subfield_names : $_->name } shift->fields;
+}
+
 sub fields
 {
   my($self) = shift;
@@ -386,6 +419,12 @@ sub fields
   return wantarray ? @{$self->{'field_list'}} : $self->{'field_list'};
 }
 
+sub num_fields
+{
+  my $fields = shift->fields;
+  return $fields && @$fields ? scalar @$fields : 0;
+}
+
 sub field_monikers
 {
   my($self) = shift;
