@@ -7,7 +7,7 @@ use Rose::HTML::Object::Errors qw(:time);
 use Rose::HTML::Form::Field::Text;
 our @ISA = qw(Rose::HTML::Form::Field::Text);
 
-our $VERSION = '0.01';
+our $VERSION = '0.541';
 
 __PACKAGE__->add_required_html_attrs(
 {
@@ -33,13 +33,26 @@ sub validate
   return 1;
 }
 
+if(__PACKAGE__->localizer->auto_load_messages)
+{
+  __PACKAGE__->localizer->load_all_messages;
+}
+
 1;
 
 __DATA__
 
 [% LOCALE en %]
 
-TIME_INVALID_MINUTE = "Invalid seconds."
+TIME_INVALID_SECONDS = "Invalid seconds."
+
+[% LOCALE de %]
+
+TIME_INVALID_SECONDS = "Ungültige Sekunden."
+
+[% LOCALE fr %]
+
+TIME_INVALID_SECONDS = "Secondes invalides."
 
 __END__
 
